@@ -39,20 +39,14 @@ SearchBar::SearchBar(QWidget *parent)
 
     // Get the widget that currently has the focus so we can properly
     // restore it when the filter bar is closed.
-    QWidget* widgetWindow = (parent ? parent->window() : 0);
-    m_focusWidget = (widgetWindow ? widgetWindow->focusWidget() : 0);
+    QWidget* widgetWindow = (parent ? parent->window() : nullptr);
+    m_focusWidget = (widgetWindow ? widgetWindow->focusWidget() : nullptr);
 
     // Initialize the user interface...
     m_ui.setupUi(this);
     m_ui.optionsButton->addAction(m_ui.actionMatchCase);
     m_ui.optionsButton->addAction(m_ui.actionHighlightMatch);
     m_ui.optionsButton->addAction(m_ui.actionSearchAutomatically);
-    m_ui.closeButton->setIcon(QIcon::fromTheme(QStringLiteral("dialog-close")));
-    m_ui.previousButton->setIcon(QIcon::fromTheme(QStringLiteral("go-up-search")));
-    m_ui.nextButton->setIcon(QIcon::fromTheme(QStringLiteral("go-down-search")));
-    m_ui.previousButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
-    m_ui.nextButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
-    m_ui.searchInfo->setText(i18nc("label for input line to find text", "&Find:"));
 
     setFocusProxy(m_ui.searchComboBox);
     
@@ -183,7 +177,7 @@ bool SearchBar::event(QEvent* e)
             close();
             if (m_focusWidget) {
                 m_focusWidget->setFocus();
-                m_focusWidget = 0;
+                m_focusWidget = nullptr;
             }
             return true;
         }
